Organic & Metal-Organic Cages
=============================

.. toctree::
  :maxdepth: 1

  Overview and Examples <_autosummary/stk.cage.Cage>

Organic
-------

.. toctree::
  :maxdepth: 1

  One Plus One <_autosummary/stk.cage.OnePlusOne>
  Two Plus Two <_autosummary/stk.cage.TwoPlusTwo>
  Two Plus Three <_autosummary/stk.cage.TwoPlusThree>
  Two Plus Four <_autosummary/stk.cage.TwoPlusFour>
  Three Plus Six <_autosummary/stk.cage.ThreePlusSix>
  Four Plus Four <_autosummary/stk.cage.FourPlusFour>
  Four Plus Six <_autosummary/stk.cage.FourPlusSix>
  Four Plus Six 2 <_autosummary/stk.cage.FourPlusSix2>
  Four Plus Eight <_autosummary/stk.cage.FourPlusEight>
  Five Plus Ten <_autosummary/stk.cage.FivePlusTen>
  Six Plus Eight <_autosummary/stk.cage.SixPlusEight>
  Six Plus Nine <_autosummary/stk.cage.SixPlusNine>
  Six Plus Twelve <_autosummary/stk.cage.SixPlusTwelve>
  Eight Plus Twelve <_autosummary/stk.cage.EightPlusTwelve>
  Eight Plus Sixteen <_autosummary/stk.cage.EightPlusSixteen>
  Ten Plus Twenty <_autosummary/stk.cage.TenPlusTwenty>
  Twelve Plus Thirty <_autosummary/stk.cage.TwelvePlusThirty>
  Twenty Plus Thirty <_autosummary/stk.cage.TwentyPlusThirty>

Metal-Organic
-------------

.. toctree::
  :maxdepth: 1

  M2L4 Lantern <_autosummary/stk.cage.M2L4Lantern>
  M3L3 Triangle <_autosummary/stk.cage.M3L3Triangle>
  M3L6 <_autosummary/stk.cage.M3L6>
  M4L4 Square <_autosummary/stk.cage.M4L4Square>
  M4L4 Tetrahedron <_autosummary/stk.cage.M4L4Tetrahedron>
  M4L6 Tetrahedron Spacer <_autosummary/stk.cage.M4L6TetrahedronSpacer>
  M4L6 Tetrahedron <_autosummary/stk.cage.M4L6Tetrahedron>
  M4L8 <_autosummary/stk.cage.M4L8>
  M6L2L3 Prism <_autosummary/stk.cage.M6L2L3Prism>
  M6L12 Cube <_autosummary/stk.cage.M6L12Cube>
  M8L6 Cube <_autosummary/stk.cage.M8L6Cube>
  M12L24 <_autosummary/stk.cage.M12L24>
  M24L48 <_autosummary/stk.cage.M24L48>
